@@ -5,6 +5,7 @@ namespace App\Classes\LDAP\Attribute\Binary;
 use Illuminate\Contracts\View\View;
 
 use App\Classes\LDAP\Attribute\Binary;
+use App\Ldap\Entry;
 use App\Traits\MD5Updates;
 
 /**
@@ -14,13 +15,14 @@ final class JpegPhoto extends Binary
 {
 	use MD5Updates;
 
-	public function render(bool $edit=FALSE,bool $old=FALSE,bool $new=FALSE): View
+	public function render(bool $edit=FALSE,bool $old=FALSE,bool $new=FALSE,string $langtag=Entry::TAG_NOTAG): View
 	{
 		return view('components.attribute.binary.jpegphoto')
 			->with('o',$this)
 			->with('edit',$edit)
 			->with('old',$old)
 			->with('new',$new)
+			->with('langtag',$langtag)
 			->with('f',new \finfo);
 	}
 }
\ No newline at end of file
