@@ -20,13 +20,22 @@ class Factory
 	 * Map of attributes to appropriate class
 	 */
 	public const map = [
+		'authorityrevocationlist' => CertificateList::class,
+		'cacertificate' => Certificate::class,
+		'certificaterevocationlist' => CertificateList::class,
 		'createtimestamp' => Internal\Timestamp::class,
 		'creatorsname' => Internal\DN::class,
+		'configcontext' => Schema\Generic::class,
 		'contextcsn' => Internal\CSN::class,
 		'entrycsn' => Internal\CSN::class,
 		'entrydn' => Internal\DN::class,
 		'entryuuid' => Internal\UUID::class,
 		'etag' => Internal\Etag::class,
+		'krblastfailedauth' => Attribute\NoAttrTags\Generic::class,
+		'krblastpwdchange' => Attribute\NoAttrTags\Generic::class,
+		'krblastsuccessfulauth' => Attribute\NoAttrTags\Generic::class,
+		'krbpasswordexpiration' => Attribute\NoAttrTags\Generic::class,
+		'krbloginfailedcount' => Attribute\NoAttrTags\Generic::class,
 		'krbprincipalkey' => KrbPrincipalKey::class,
 		'krbticketflags' => KrbTicketFlags::class,
 		'gidnumber' => GidNumber::class,
@@ -34,6 +43,8 @@ class Factory
 		'jpegphoto' => Binary\JpegPhoto::class,
 		'modifytimestamp' => Internal\Timestamp::class,
 		'modifiersname' => Internal\DN::class,
+		'monitorcontext' => Schema\Generic::class,
+		'namingcontexts' => Schema\Generic::class,
 		'numsubordinates' => Internal\NumSubordinates::class,
 		'objectclass' => ObjectClass::class,
 		'pwdpolicysubentry' => Internal\PwdPolicySubentry::class,
@@ -42,7 +53,9 @@ class Factory
 		'supportedcontrol' => Schema\OID::class,
 		'supportedextension' => Schema\OID::class,
 		'supportedfeatures' => Schema\OID::class,
+		'supportedldapversion' => Schema\Generic::class,
 		'supportedsaslmechanisms' => Schema\Mechanisms::class,
+		'usercertificate' => Certificate::class,
 		'userpassword' => Password::class,
 	];
 
