@@ -15,6 +15,8 @@ final class KrbPrincipalKey extends Attribute
 {
 	use MD5Updates;
 
+	protected(set) bool $no_attr_tags = TRUE;
+
 	public function render(bool $edit=FALSE,bool $old=FALSE,bool $new=FALSE): View
 	{
 		return view('components.attribute.krbprincipalkey')
@@ -24,18 +26,16 @@ final class KrbPrincipalKey extends Attribute
 			->with('new',$new);
 	}
 
-	public function render_item_old(int $key): ?string
+	public function render_item_old(string $dotkey): ?string
 	{
-		$pw = Arr::get($this->values_old,$key);
-		return $pw
+		return parent::render_item_old($dotkey)
 			? str_repeat('*',16)
 			: NULL;
 	}
 
-	public function render_item_new(int $key): ?string
+	public function render_item_new(string $dotkey): ?string
 	{
-		$pw = Arr::get($this->values,$key);
-		return $pw
+		return parent::render_item_new($dotkey)
 			? str_repeat('*',16)
 			: NULL;
 	}
