@@ -57,11 +57,12 @@ class HomeController extends Controller
 
 		$o = new Entry;
 
-		if (count(array_filter($x=old('objectclass',$request->objectclass)))) {
+		if (count($x=array_filter(old('objectclass',$request->objectclass)))) {
 			$o->objectclass = $x;
 
+			// Also add in our required attributes
 			foreach($o->getAvailableAttributes()->filter(fn($item)=>$item->required) as $ao)
-				$o->{$ao->name} = '';
+				$o->{$ao->name} = [Entry::TAG_NOTAG=>''];
 
 			$o->setRDNBase($key['dn']);
 		}
@@ -92,10 +93,12 @@ class HomeController extends Controller
 
 		return $request->noheader
 			? view(sprintf('components.attribute.widget.%s',$id))
-				->with('o',Factory::create($dn,$id,[],$request->objectclasses))
+				->with('o',Factory::create(dn: $dn,attribute: $id,values: [],oc: $request->objectclasses))
 				->with('value',$request->value)
+				->with('langtag',Entry::TAG_NOTAG)
 				->with('loop',$xx)
-			: new AttributeType(Factory::create($dn,$id,[],$request->objectclasses),TRUE)->render();
+			: new AttributeType(Factory::create($dn,$id,[],$request->objectclasses),new: TRUE,edit: TRUE)
+				->render();
 	}
 
 	public function entry_create(EntryAddRequest $request): \Illuminate\Http\RedirectResponse
@@ -188,8 +191,6 @@ class HomeController extends Controller
 
 		$result = (new Entry)
 			->query()
-			//->cache(Carbon::now()->addSeconds(Config::get('ldap.cache.time')))
-			//->select(['*'])
 			->setDn($dn)
 			->recursive()
 			->get();
@@ -237,7 +238,7 @@ class HomeController extends Controller
 		$password = $o->getObject('userpassword');
 
 		$result = collect();
-		foreach ($password as $key => $value) {
+		foreach ($password->values->dot() as $key => $value) {
 			$hash = $password->hash($value);
 			$compare = Arr::get($request->password,$key);
 			//Log::debug(sprintf('comparing [%s] with [%s] type [%s]',$value,$compare,$hash::id()),['object'=>$hash]);
@@ -269,19 +270,22 @@ class HomeController extends Controller
 		// We need to process and encrypt the password
 		if ($request->userpassword) {
 			$passwords = [];
-			foreach ($request->userpassword as $key => $value) {
+			$po = $o->getObject('userpassword');
+			foreach (Arr::dot($request->userpassword) as $dotkey => $value) {
 				// If the password is still the MD5 of the old password, then it hasnt changed
-				if (($old=Arr::get($o->userpassword,$key)) && ($value === md5($old))) {
-					array_push($passwords,$old);
+				if (($old=Arr::get($po,$dotkey)) && ($value === md5($old))) {
+					$passwords[$dotkey] = $value;
 					continue;
 				}
 
 				if ($value) {
-					$type = Arr::get($request->userpassword_hash,$key);
-					array_push($passwords,Password::hash_id($type)->encode($value));
+					$type = Arr::get($request->userpassword_hash,$dotkey);
+					$passwords[$dotkey] = Password::hash_id($type)
+						->encode($value);
 				}
 			}
-			$o->userpassword = $passwords;
+
+			$o->userpassword = Arr::undot($passwords);
 		}
 
 		if (! $o->getDirty())
@@ -347,7 +351,7 @@ class HomeController extends Controller
 
 		return Redirect::to('/')
 			->withInput()
-			->with('updated',collect($dirty)->map(fn($key,$item)=>$o->getObject($item)));
+			->with('updated',collect($dirty)->map(fn($item,$key)=>$o->getObject(collect(explode(';',$key))->first())));
 	}
 
 	/**
@@ -372,11 +376,12 @@ class HomeController extends Controller
 			->with('bases',$this->bases());
 
 		// If we are rendering a DN, rebuild our object
-		$o = config('server')->fetch($key['dn']);
+		if ($key['dn']) {
+			$o = config('server')->fetch($key['dn']);
 
-		// @todo We need to dynamically exclude request items, so we dont need to add them here
-		foreach (collect(old())->except(['dn','_token','userpassword_hash']) as $attr => $value)
-			$o->{$attr} = $value;
+			foreach (collect(old())->except(['key','dn','step','_token','userpassword_hash']) as $attr => $value)
+				$o->{$attr} = $value;
+		}
 
 		return match ($key['cmd']) {
 			'create' => $view
@@ -386,7 +391,13 @@ class HomeController extends Controller
 			'dn' => $view
 				->with('dn',$key['dn'])
 				->with('o',$o)
-				->with('page_actions',collect(['edit'=>TRUE])),
+				->with('page_actions',collect([
+					'copy'=>FALSE,
+					'create'=>FALSE,
+					'delete'=>TRUE,
+					'edit'=>TRUE,
+					'export'=>TRUE,
+				])),
 
 			'import' => $view,
 
