@@ -1,11 +1,11 @@
 <!-- @todo We are not handling redirect backs yet with updated passwords -->
 <!-- $o=Password::class -->
-<x-attribute.layout :edit="$edit ?? FALSE" :new="$new ?? FALSE" :o="$o">
-	@foreach($o->values_old as $value)
+<x-attribute.layout :edit="$edit" :new="$new" :o="$o" :langtag="$langtag">
+	@foreach($o->tagValuesOld($langtag) as $key => $value)
 		@if($edit)
 			<div class="input-group has-validation mb-3">
-				<x-form.select id="userpassword_hash_{{$loop->index}}" name="userpassword_hash[]" :value="$o->hash($value)->id()" :options="$helpers" allowclear="false" :disabled="true"/>
-				<input type="password" @class(['form-control','is-invalid'=>($e=$errors->get($o->name_lc.'.'.$loop->index)),'mb-1','border-focus'=>$o->values->contains($value)]) name="{{ $o->name_lc }}[]" value="{{ md5($value) }}" @readonly(true)>
+				<x-form.select id="userpassword_hash_{{$loop->index}}" name="userpassword_hash[{{ $langtag }}][]" :value="$o->hash($value)->id()" :options="$helpers" allowclear="false" :disabled="true"/>
+				<input type="password" @class(['form-control','is-invalid'=>($e=$errors->get($o->name_lc.'.'.$langtag.'.'.$loop->index)),'mb-1','border-focus'=>! $o->tagValuesOld($langtag)->contains($value)]) name="{{ $o->name_lc }}[{{ $langtag }}][]" value="{{ md5($value) }}" @readonly(true)>
 
 				<div class="invalid-feedback pb-2">
 					@if($e)
@@ -14,7 +14,7 @@
 				</div>
 			</div>
 		@else
-			{{ (($x=$o->hash($value)) && ($x::id() !== '*clear*')) ? sprintf('{%s}',$x::shortid()) : '' }}{{ str_repeat('*',16) }}
+			{{ $o->render_item_old($langtag.'.'.$key) }}
 		@endif
 	@endforeach
 </x-attribute.layout>
