@@ -1,15 +1,27 @@
+@use(App\Classes\LDAP\Attribute\Certificate)
+@use(App\Classes\LDAP\Attribute\CertificateList)
 @use(App\Classes\LDAP\Attribute\Binary\JpegPhoto)
 @use(App\Classes\LDAP\Attribute\ObjectClass)
 @php($clone=FALSE)
 <span class="p-0 m-0">
 	@if($o->is_rdn)
-		<br/>
-		<span class="btn btn-sm btn-outline-focus mt-3" disabled><i class="fas fa-fw fa-exchange"></i> @lang('Rename')</span>
+		<button class="btn btn-sm btn-outline-focus mt-3" disabled><i class="fas fa-fw fa-exchange"></i> @lang('Rename')</button>
 	@elseif($edit && $o->can_addvalues)
 		@switch(get_class($o))
-			@case(JpegPhoto::class)
-				<span @class(['btn','btn-sm','btn-outline-primary','mt-3','addable','d-none'=>(! $new)]) id="{{ $o->name_lc }}" disabled><i class="fas fa-fw fa-plus"></i> @lang('Upload JpegPhoto')</span>
-
+			@case(Certificate::class)
+			@case(CertificateList::class)
+				<span @class(['btn','btn-sm','btn-outline-primary','mt-3','addable','d-none'=>(! $new)]) id="{{ $o->name }}-replace" disabled><i class="fas fa-fw fa-certificate"></i> @lang('Replace')</span>
+				@section('page-scripts')
+					<script type="text/javascript">
+							$(document).ready(function() {
+								$('#{{ $o->name }}-replace.addable').click(function(e) {
+									alert('Sorry, not implemented yet');
+									e.preventDefault();
+									return false;
+								});
+							});
+					</script>
+				@append
 				@break
 
 			@case(ObjectClass::class)
@@ -51,6 +63,9 @@
 									if (added_oc.indexOf(item) !== -1)
 										return;
 
+									// Add our new OC to the list of OCs
+									oc.push(item);
+
 									// Add attribute to the page
 									$.ajax({
 										method: 'POST',
@@ -151,7 +166,7 @@
 														if (x.length) {
 															x.remove();
 
-															// Add this to the must attrs list, because its been rendered
+														// Add this to the must attrs list, because its been rendered
 														} else {
 															attrs.push(mayitem);
 														}
@@ -217,8 +232,24 @@
 				@append
 				@break
 
+			@case(JpegPhoto::class)
+				<span @class(['btn','btn-sm','btn-outline-primary','mt-3','addable','d-none'=>(! $new)]) id="{{ $o->name }}-upload" disabled><i class="fas fa-fw fa-file-arrow-up"></i> @lang('Upload JpegPhoto')</span>
+				@section('page-scripts')
+					<script type="text/javascript">
+							$(document).ready(function() {
+								$('#{{ $o->name }}-upload.addable').click(function(e) {
+									alert('Sorry, not implemented yet');
+									e.preventDefault();
+									return false;
+								});
+							});
+					</script>
+				@append
+				@break
+
 			<!-- All other attributes -->
 			@default
+				@if($o->isDynamic()) @break @endif
 				@php($clone=TRUE)
 				<span @class(['btn','btn-sm','btn-outline-primary','mt-3','addable','d-none'=>(! $new)]) id="{{ $o->name }}-addnew"><i class="fas fa-fw fa-plus"></i> @lang('Add Value')</span>
 
@@ -229,8 +260,11 @@
 								// Create a new entry when Add Value clicked
 								$('#{{ $o->name }}-addnew.addable').click(function (item) {
 									var cln = $(this).parent().parent().find('input:last').parent().clone();
-									cln.find('input:last').attr('value','').attr('placeholder', '[@lang('NEW')]');
-									cln.appendTo('#'+item.currentTarget.id.replace('-addnew',''));
+									cln.find('input:last')
+										.attr('value','')
+										.attr('placeholder', '[@lang('NEW')]')
+										.addClass('border-focus')
+										.appendTo('#'+item.currentTarget.id.replace('-addnew',''));
 								});
 							});
 						</script>
