@@ -13,10 +13,9 @@
 
 			<div class="row">
 				<div class="col-12 pt-2">
-					<x-form.select id="newattr" label="Select from..." :options="$o->getMissingAttributes()->sortBy('name')->map(fn($item)=>['id'=>$item->name,'value'=>$item->name_lc])"/>
+					<x-form.select id="newattr" label="Select from..." :options="$o->getMissingAttributes()->sortBy('name')->unique('name')->map(fn($item)=>['id'=>$item->name,'value'=>$item->name_lc])"/>
 				</div>
 			</div>
 		</div>
 	</div>
-	<div class="col-2"></div>
 </div>
\ No newline at end of file
