@@ -26,6 +26,12 @@
 						<x-attribute :o="$o->getObject('entryuuid')" :na="__('Unknown')"/>
 					</th>
 				</tr>
+				@if($langtags->count())
+					<tr class="mt-1">
+						<td class="p-0 pe-2">Tags</td>
+						<th class="p-0">{{ $langtags->join(', ') }}</th>
+					</tr>
+				@endif
 			</table>
 		</td>
 	</tr>
