@@ -1,12 +1,15 @@
+@use(App\Ldap\Entry)
+
 @extends('layouts.dn')
 
 @section('page_title')
-	@include('fragment.dn.header',['o'=>($oo=$server->fetch(old('container',$container)))])
+	@include('fragment.dn.header',[
+		'o'=>($oo=$server->fetch(old('container',$container))),
+		'langtags'=>collect(),
+	])
 @endsection
 
 @section('main-content')
-	<x-error/>
-
 	<div class="row">
 		<div class="offset-1 col-10">
 			<div class="main-card mb-3 card">
@@ -28,7 +31,8 @@
 									<div class="col-12 col-md-6">
 										<x-form.select
 											id="objectclass"
-											name="objectclass[]"
+											name="objectclass[{{ Entry::TAG_NOTAG }}][]"
+											old="objectclass.{{ Entry::TAG_NOTAG }}"
 											:label="__('Select a Structural ObjectClass...')"
 											:options="($oc=$server->schema('objectclasses'))
 												->filter(fn($item)=>$item->isStructural())
@@ -66,8 +70,8 @@
 @endsection
 
 @section('page-scripts')
+
 	<script type="text/javascript">
-		var oc = {!! $oo->getObject('objectclass')->values !!};
 		var rdn_attr;
 
 		function editmode() {
@@ -96,31 +100,35 @@
 		}
 
 		$(document).ready(function() {
-			$('#newattr').on('change',function(item) {
-				$.ajax({
-					type: 'POST',
-					beforeSend: function() {},
-					success: function(data) {
-						$('#newattrs').append(data);
-					},
-					error: function(e) {
-						if (e.status != 412)
-							alert('That didnt work? Please try again....');
-					},
-					url: '{{ url('entry/attr/add') }}/'+item.target.value,
-					data: {
-						objectclasses: oc,
-					},
-					cache: false
+			@if($step === 2)
+				var oc = {!! $o->getObject('objectclass')->values !!};
+
+				$('#newattr').on('change',function(item) {
+					$.ajax({
+						type: 'POST',
+						url: '{{ url('entry/attr/add') }}/'+item.target.value,
+						data: {
+							objectclasses: oc,
+						},
+						cache: false,
+						beforeSend: function() {},
+						success: function(data) {
+							$('#newattrs').append(data);
+						},
+						error: function(e) {
+							if (e.status != 412)
+								alert('That didnt work? Please try again....');
+						},
+					});
+
+					// Remove the option from the list
+					$(this).find('[value="'+item.target.value+'"]').remove()
+
+					// If there are no more options
+					if ($(this).find("option").length === 1)
+						$('#newattr-select').remove();
 				});
-
-				// Remove the option from the list
-				$(this).find('[value="'+item.target.value+'"]').remove()
-
-				// If there are no more options
-				if ($(this).find("option").length === 1)
-					$('#newattr-select').remove();
-			});
+			@endif
 
 			editmode();
 		});
